@@ -1,9 +1,9 @@
 // Copyright (c) 2012-2013, IGN France.
 // Copyright (c) 2012-2022, Oslandia.
-// SPDX-License-Identifier: GPL-2.0-or-later
+// SPDX-License-Identifier: LGPL-2.0-or-later
 
-#ifndef _SFCGAL_KERNEL_H_
-#define _SFCGAL_KERNEL_H_
+#ifndef SFCGAL_KERNEL_H_
+#define SFCGAL_KERNEL_H_
 
 #include <CGAL/Exact_predicates_exact_constructions_kernel.h>
 
@@ -12,7 +12,8 @@ namespace SFCGAL {
 /**
  * default Kernel
  */
-typedef CGAL::Exact_predicates_exact_constructions_kernel Kernel;
+
+using Kernel = CGAL::Exact_predicates_exact_constructions_kernel;
 
 /**
  * Quotient type
