@@ -2,8 +2,8 @@
 // Copyright (c) 2012-2022, Oslandia.
 // SPDX-License-Identifier: LGPL-2.0-or-later
 
-#include <SFCGAL/GeometryVisitor.h>
-#include <SFCGAL/Surface.h>
+#include "SFCGAL/Surface.h"
+#include "SFCGAL/GeometryVisitor.h"
 
 namespace SFCGAL {
 
