@@ -2,11 +2,11 @@
 // Copyright (c) 2012-2022, Oslandia.
 // SPDX-License-Identifier: LGPL-2.0-or-later
 
-#ifndef _SFCGAL_TRANSFORM_H_
-#define _SFCGAL_TRANSFORM_H_
+#ifndef SFCGAL_TRANSFORM_H_
+#define SFCGAL_TRANSFORM_H_
 
-#include <SFCGAL/Geometry.h>
-#include <SFCGAL/GeometryVisitor.h>
+#include "SFCGAL/Geometry.h"
+#include "SFCGAL/GeometryVisitor.h"
 
 namespace SFCGAL {
 
