@@ -1,19 +1,19 @@
 // Copyright (c) 2022-2022, Oslandia.
 // SPDX-License-Identifier: LGPL-2.0-or-later
 
-#include <SFCGAL/algorithm/alphaShapes.h>
+#include "SFCGAL/algorithm/alphaShapes.h"
 
-#include <SFCGAL/GeometryCollection.h>
-#include <SFCGAL/MultiPolygon.h>
-#include <SFCGAL/Polygon.h>
-#include <SFCGAL/PolyhedralSurface.h>
-#include <SFCGAL/Triangle.h>
-#include <SFCGAL/TriangulatedSurface.h>
+#include "SFCGAL/GeometryCollection.h"
+#include "SFCGAL/MultiPolygon.h"
+#include "SFCGAL/Polygon.h"
+#include "SFCGAL/PolyhedralSurface.h"
+#include "SFCGAL/Triangle.h"
+#include "SFCGAL/TriangulatedSurface.h"
 
-#include <SFCGAL/detail/GetPointsVisitor.h>
+#include "SFCGAL/detail/GetPointsVisitor.h"
 
-#include <SFCGAL/Exception.h>
-#include <SFCGAL/Kernel.h>
+#include "SFCGAL/Exception.h"
+#include "SFCGAL/Kernel.h"
 #include <boost/format.hpp>
 
 #include <CGAL/Alpha_shape_2.h>
