@@ -2,13 +2,13 @@
 // Copyright (c) 2012-2022, Oslandia.
 // SPDX-License-Identifier: LGPL-2.0-or-later
 
-#ifndef _SFCGAL_ALGORITHM_ISVALID_H_
-#define _SFCGAL_ALGORITHM_ISVALID_H_
+#ifndef SFCGAL_ALGORITHM_ISVALID_H_
+#define SFCGAL_ALGORITHM_ISVALID_H_
 
-#include <SFCGAL/Geometry.h>
-#include <SFCGAL/Validity.h>
-#include <SFCGAL/algorithm/force2D.h>
-#include <SFCGAL/algorithm/force3D.h>
+#include "SFCGAL/Geometry.h"
+#include "SFCGAL/Validity.h"
+#include "SFCGAL/algorithm/force2D.h"
+#include "SFCGAL/algorithm/force3D.h"
 
 namespace SFCGAL {
 
