@@ -2,12 +2,12 @@
 // Copyright (c) 2012-2022, Oslandia.
 // SPDX-License-Identifier: LGPL-2.0-or-later
 
-#include <SFCGAL/algorithm/length.h>
+#include "SFCGAL/algorithm/length.h"
 
-#include <SFCGAL/GeometryCollection.h>
-#include <SFCGAL/LineString.h>
+#include "SFCGAL/GeometryCollection.h"
+#include "SFCGAL/LineString.h"
 
-#include <SFCGAL/Exception.h>
+#include "SFCGAL/Exception.h"
 
 namespace SFCGAL::algorithm {
 
