@@ -2,19 +2,19 @@
 // Copyright (c) 2012-2022, Oslandia.
 // SPDX-License-Identifier: LGPL-2.0-or-later
 
-#include <SFCGAL/algorithm/isValid.h>
-#include <SFCGAL/algorithm/minkowskiSum.h>
+#include "SFCGAL/algorithm/minkowskiSum.h"
+#include "SFCGAL/algorithm/isValid.h"
 
-#include <SFCGAL/GeometryCollection.h>
-#include <SFCGAL/LineString.h>
-#include <SFCGAL/Point.h>
-#include <SFCGAL/Polygon.h>
-#include <SFCGAL/PolyhedralSurface.h>
-#include <SFCGAL/Solid.h>
-#include <SFCGAL/Triangle.h>
-#include <SFCGAL/TriangulatedSurface.h>
+#include "SFCGAL/GeometryCollection.h"
+#include "SFCGAL/LineString.h"
+#include "SFCGAL/Point.h"
+#include "SFCGAL/Polygon.h"
+#include "SFCGAL/PolyhedralSurface.h"
+#include "SFCGAL/Solid.h"
+#include "SFCGAL/Triangle.h"
+#include "SFCGAL/TriangulatedSurface.h"
 
-#include <SFCGAL/detail/polygonSetToMultiPolygon.h>
+#include "SFCGAL/detail/polygonSetToMultiPolygon.h"
 
 #include <CGAL/Polygon_2.h>
 #include <CGAL/Polygon_set_2.h>
