@@ -2,15 +2,15 @@
 // Copyright (c) 2012-2022, Oslandia.
 // SPDX-License-Identifier: LGPL-2.0-or-later
 
-#include <SFCGAL/algorithm/orientation.h>
+#include "SFCGAL/algorithm/orientation.h"
 
-#include <SFCGAL/algorithm/ConsistentOrientationBuilder.h>
+#include "SFCGAL/algorithm/ConsistentOrientationBuilder.h"
 
-#include <SFCGAL/detail/graph/GeometryGraph.h>
-#include <SFCGAL/detail/graph/GeometryGraphBuilder.h>
-#include <SFCGAL/detail/graph/algorithm/isHalfEdge.h>
+#include "SFCGAL/detail/graph/GeometryGraph.h"
+#include "SFCGAL/detail/graph/GeometryGraphBuilder.h"
+#include "SFCGAL/detail/graph/algorithm/isHalfEdge.h"
 
-#include <SFCGAL/detail/graph/algorithm/orientation.h>
+#include "SFCGAL/detail/graph/algorithm/orientation.h"
 
 namespace SFCGAL::algorithm {
 
