@@ -2,13 +2,13 @@
 // Copyright (c) 2012-2022, Oslandia.
 // SPDX-License-Identifier: LGPL-2.0-or-later
 
-#ifndef _SFCGAL_ALGORITHM_ORIENTATION_H_
-#define _SFCGAL_ALGORITHM_ORIENTATION_H_
+#ifndef SFCGAL_ALGORITHM_ORIENTATION_H_
+#define SFCGAL_ALGORITHM_ORIENTATION_H_
 
-#include <SFCGAL/config.h>
+#include "SFCGAL/config.h"
 
-#include <SFCGAL/Geometry.h>
-#include <SFCGAL/Kernel.h>
+#include "SFCGAL/Geometry.h"
+#include "SFCGAL/Kernel.h"
 
 #include <CGAL/Polygon_2.h>
 #include <CGAL/Polygon_with_holes_2.h>
