@@ -2,12 +2,12 @@
 // Copyright (c) 2012-2022, Oslandia.
 // SPDX-License-Identifier: LGPL-2.0-or-later
 
-#ifndef _SFCGAL_ALGORITHM_TESSELATE_H_
-#define _SFCGAL_ALGORITHM_TESSELATE_H_
+#ifndef SFCGAL_ALGORITHM_TESSELATE_H_
+#define SFCGAL_ALGORITHM_TESSELATE_H_
 
-#include <SFCGAL/config.h>
+#include "SFCGAL/config.h"
 
-#include <SFCGAL/Geometry.h>
+#include "SFCGAL/Geometry.h"
 
 namespace SFCGAL {
 namespace algorithm {
