@@ -2,56 +2,63 @@
 // Copyright (c) 2012-2022, Oslandia.
 // SPDX-License-Identifier: LGPL-2.0-or-later
 
-#include <SFCGAL/Geometry.h>
-#include <SFCGAL/GeometryCollection.h>
-#include <SFCGAL/LineString.h>
-#include <SFCGAL/MultiLineString.h>
-#include <SFCGAL/MultiPoint.h>
-#include <SFCGAL/MultiPolygon.h>
-#include <SFCGAL/Point.h>
-#include <SFCGAL/Polygon.h>
-#include <SFCGAL/PolyhedralSurface.h>
-#include <SFCGAL/PreparedGeometry.h>
-#include <SFCGAL/Solid.h>
-#include <SFCGAL/Triangle.h>
-#include <SFCGAL/TriangulatedSurface.h>
-#include <SFCGAL/version.h>
+#include "SFCGAL/Geometry.h"
+#include "SFCGAL/GeometryCollection.h"
+#include "SFCGAL/LineString.h"
+#include "SFCGAL/MultiLineString.h"
+#include "SFCGAL/MultiPoint.h"
+#include "SFCGAL/MultiPolygon.h"
+#include "SFCGAL/MultiSolid.h"
+#include "SFCGAL/Point.h"
+#include "SFCGAL/Polygon.h"
+#include "SFCGAL/PolyhedralSurface.h"
+#include "SFCGAL/PreparedGeometry.h"
+#include "SFCGAL/Solid.h"
+#include "SFCGAL/Triangle.h"
+#include "SFCGAL/TriangulatedSurface.h"
+#include "SFCGAL/version.h"
 
-#include <SFCGAL/capi/sfcgal_c.h>
+#include "SFCGAL/capi/sfcgal_c.h"
 
-#include <SFCGAL/detail/io/Serialization.h>
-#include <SFCGAL/io/ewkt.h>
-#include <SFCGAL/io/wkb.h>
-#include <SFCGAL/io/wkt.h>
+#include "SFCGAL/detail/io/Serialization.h"
+#include "SFCGAL/io/OBJ.h"
+#include "SFCGAL/io/ewkt.h"
+#include "SFCGAL/io/vtk.h"
+#include "SFCGAL/io/wkb.h"
+#include "SFCGAL/io/wkt.h"
 
 #if !_MSC_VER
-#include <SFCGAL/algorithm/alphaShapes.h>
+#include "SFCGAL/algorithm/alphaShapes.h"
 #endif
-#include <SFCGAL/algorithm/area.h>
-#include <SFCGAL/algorithm/convexHull.h>
-#include <SFCGAL/algorithm/covers.h>
-#include <SFCGAL/algorithm/difference.h>
-#include <SFCGAL/algorithm/distance.h>
-#include <SFCGAL/algorithm/distance3d.h>
-#include <SFCGAL/algorithm/extrude.h>
-#include <SFCGAL/algorithm/intersection.h>
-#include <SFCGAL/algorithm/intersects.h>
-#include <SFCGAL/algorithm/isValid.h>
-#include <SFCGAL/algorithm/lineSubstring.h>
-#include <SFCGAL/algorithm/minkowskiSum.h>
-#include <SFCGAL/algorithm/offset.h>
-#include <SFCGAL/algorithm/partition_2.h>
-#include <SFCGAL/algorithm/plane.h>
-#include <SFCGAL/algorithm/straightSkeleton.h>
-#include <SFCGAL/algorithm/tesselate.h>
-#include <SFCGAL/algorithm/union.h>
-#include <SFCGAL/algorithm/visibility.h>
-#include <SFCGAL/algorithm/volume.h>
-#include <SFCGAL/triangulate/triangulate2DZ.h>
+#include "SFCGAL/algorithm/area.h"
+#include "SFCGAL/algorithm/buffer3D.h"
+#include "SFCGAL/algorithm/convexHull.h"
+#include "SFCGAL/algorithm/covers.h"
+#include "SFCGAL/algorithm/difference.h"
+#include "SFCGAL/algorithm/distance.h"
+#include "SFCGAL/algorithm/distance3d.h"
+#include "SFCGAL/algorithm/extrude.h"
+#include "SFCGAL/algorithm/intersection.h"
+#include "SFCGAL/algorithm/intersects.h"
+#include "SFCGAL/algorithm/isValid.h"
+#include "SFCGAL/algorithm/lineSubstring.h"
+#include "SFCGAL/algorithm/minkowskiSum.h"
+#include "SFCGAL/algorithm/offset.h"
+#include "SFCGAL/algorithm/partition_2.h"
+#include "SFCGAL/algorithm/plane.h"
+#include "SFCGAL/algorithm/rotate.h"
+#include "SFCGAL/algorithm/scale.h"
+#include "SFCGAL/algorithm/straightSkeleton.h"
+#include "SFCGAL/algorithm/tesselate.h"
+#include "SFCGAL/algorithm/translate.h"
+#include "SFCGAL/algorithm/union.h"
+#include "SFCGAL/algorithm/visibility.h"
+#include "SFCGAL/algorithm/volume.h"
+#include "SFCGAL/triangulate/triangulate2DZ.h"
 
-#include <SFCGAL/detail/transform/ForceOrderPoints.h>
-#include <SFCGAL/detail/transform/ForceZOrderPoints.h>
-#include <SFCGAL/detail/transform/RoundTransform.h>
+#include "SFCGAL/detail/transform/ForceOrderPoints.h"
+#include "SFCGAL/detail/transform/ForceZOrderPoints.h"
+#include "SFCGAL/detail/transform/RoundTransform.h"
 #include <cmath>
 
 //
@@ -254,7 +261,7 @@ sfcgal_geometry_as_text(const sfcgal_geometry_t *pgeom, char **buffer,
       std::string wkt =
           reinterpret_cast<const SFCGAL::Geometry *>(pgeom)->asText();
       *buffer = (char *)sfcgal_alloc_handler(wkt.size() + 1); *len = wkt.size();
-      strncpy(*buffer, wkt.c_str(), *len);)
+      strncpy(*buffer, wkt.c_str(), *len); (*buffer)[*len]         = '\0';)
 }
 
 extern "C" void
@@ -266,7 +273,7 @@ sfcgal_geometry_as_text_decim(const sfcgal_geometry_t *pgeom, int numDecimals,
           reinterpret_cast<const SFCGAL::Geometry *>(pgeom)->asText(
               numDecimals);
       *buffer = (char *)sfcgal_alloc_handler(wkt.size() + 1); *len = wkt.size();
-      strncpy(*buffer, wkt.c_str(), *len);)
+      strncpy(*buffer, wkt.c_str(), *len); (*buffer)[*len]         = '\0';)
 }
 
 extern "C" void
@@ -275,11 +282,70 @@ sfcgal_geometry_as_wkb(const sfcgal_geometry_t *pgeom, char **buffer,
 {
   SFCGAL_GEOMETRY_CONVERT_CATCH_TO_ERROR_NO_RET(
       std::string wkb =
-          reinterpret_cast<const SFCGAL::Geometry *>(pgeom)->asWkb();
+          reinterpret_cast<const SFCGAL::Geometry *>(pgeom)->asWkb(
+              boost::endian::order::native, false);
+      *buffer = (char *)sfcgal_alloc_handler(wkb.size() + 1); *len = wkb.size();
+      memcpy(*buffer, wkb.data(), *len);)
+}
+
+extern "C" void
+sfcgal_geometry_as_hexwkb(const sfcgal_geometry_t *pgeom, char **buffer,
+                          size_t *len)
+{
+  SFCGAL_GEOMETRY_CONVERT_CATCH_TO_ERROR_NO_RET(
+      std::string wkb =
+          reinterpret_cast<const SFCGAL::Geometry *>(pgeom)->asWkb(
+              boost::endian::order::native, true);
       *buffer = (char *)sfcgal_alloc_handler(wkb.size() + 1); *len = wkb.size();
       strncpy(*buffer, wkb.c_str(), *len);)
 }
 
+extern "C" auto
+sfcgal_geometry_as_vtk_file(const sfcgal_geometry_t *pgeom,
+                            const char              *filename) -> void
+{
+  SFCGAL_GEOMETRY_CONVERT_CATCH_TO_ERROR_NO_RET(
+      SFCGAL::io::VTK::save(*reinterpret_cast<const SFCGAL::Geometry *>(pgeom),
+                            filename);)
+}
+
+extern "C" auto
+sfcgal_geometry_as_vtk(const sfcgal_geometry_t *pgeom, char **buffer,
+                       size_t *len) -> void
+{
+  SFCGAL_GEOMETRY_CONVERT_CATCH_TO_ERROR_NO_RET(
+      std::string obj = SFCGAL::io::VTK::saveToString(
+          *reinterpret_cast<const SFCGAL::Geometry *>(pgeom));
+      *len = obj.size(); *buffer = (char *)sfcgal_alloc_handler(*len + 1);
+      if (*buffer) {
+        memcpy(*buffer, obj.c_str(), *len);
+        (*buffer)[*len] = '\0';
+      } else { *len = 0; })
+}
+
+extern "C" void
+sfcgal_geometry_as_obj_file(const sfcgal_geometry_t *pgeom,
+                            const char              *filename)
+{
+  SFCGAL_GEOMETRY_CONVERT_CATCH_TO_ERROR_NO_RET(
+      SFCGAL::io::OBJ::save(*reinterpret_cast<const SFCGAL::Geometry *>(pgeom),
+                            filename);)
+}
+
+extern "C" void
+sfcgal_geometry_as_obj(const sfcgal_geometry_t *pgeom, char **buffer,
+                       size_t *len)
+{
+  SFCGAL_GEOMETRY_CONVERT_CATCH_TO_ERROR_NO_RET(
+      std::string obj = SFCGAL::io::OBJ::saveToString(
+          *reinterpret_cast<const SFCGAL::Geometry *>(pgeom));
+      *len = obj.size(); *buffer = (char *)sfcgal_alloc_handler(*len + 1);
+      if (*buffer) {
+        memcpy(*buffer, obj.c_str(), *len);
+        (*buffer)[*len] = '\0';
+      } else { *len = 0; })
+}
+
 /**
  * Point
  */
@@ -556,6 +622,13 @@ sfcgal_multi_polygon_create() -> sfcgal_geometry_t *
       return static_cast<SFCGAL::Geometry *>(new SFCGAL::MultiPolygon());)
 }
 
+extern "C" auto
+sfcgal_multi_solid_create() -> sfcgal_geometry_t *
+{
+  SFCGAL_GEOMETRY_CONVERT_CATCH_TO_ERROR(
+      return static_cast<SFCGAL::Geometry *>(new SFCGAL::MultiSolid());)
+}
+
 /**
  * Polyhedral surface
  */
@@ -756,7 +829,11 @@ extern "C" auto
 sfcgal_io_read_wkb(const char *str, size_t len) -> sfcgal_geometry_t *
 {
   SFCGAL_GEOMETRY_CONVERT_CATCH_TO_ERROR(
-      return SFCGAL::io::readWkb(str, len).release();)
+      if (len > 2 && str[0] == '0' &&
+          (str[1] == '0' || str[1] == '1')) return SFCGAL::io::readWkb(str, len,
+                                                                       true)
+          .release();
+      return SFCGAL::io::readWkb(str, len, false).release();)
 }
 
 extern "C" void
@@ -1485,3 +1562,224 @@ sfcgal_geometry_visibility_segment(const sfcgal_geometry_t *polygon,
 
   return result.release();
 }
+
+extern "C" auto
+
+sfcgal_geometry_translate_2d(sfcgal_geometry_t *geom, double dx, double dy)
+    -> sfcgal_geometry_t *
+{
+  const auto       *g  = reinterpret_cast<const SFCGAL::Geometry *>(geom);
+  SFCGAL::Geometry *gb = g->clone();
+  try {
+
+    SFCGAL::algorithm::translate(*gb, SFCGAL::Kernel::Vector_2(dx, dy));
+  } catch (std::exception &e) {
+    SFCGAL_WARNING("During translate(A, %g, %g):", dx, dy);
+    SFCGAL_WARNING("  with A: %s",
+                   ((const SFCGAL::Geometry *)(gb))->asText().c_str());
+    SFCGAL_ERROR("%s", e.what());
+    return nullptr;
+  }
+
+  return gb;
+}
+
+extern "C" auto
+sfcgal_geometry_translate_3d(sfcgal_geometry_t *geom, double dx, double dy,
+                             double dz) -> sfcgal_geometry_t *
+{
+  const auto       *g  = reinterpret_cast<const SFCGAL::Geometry *>(geom);
+  SFCGAL::Geometry *gb = g->clone();
+
+  try {
+    SFCGAL::algorithm::translate(*gb, SFCGAL::Kernel::Vector_3(dx, dy, dz));
+  } catch (std::exception &e) {
+    SFCGAL_WARNING("During translate(A, %g, %g, %g):", dx, dy, dz);
+    SFCGAL_WARNING("  with A: %s",
+                   ((const SFCGAL::Geometry *)(gb))->asText().c_str());
+    SFCGAL_ERROR("%s", e.what());
+    return nullptr;
+  }
+
+  return gb;
+}
+
+extern "C" auto
+sfcgal_geometry_scale(const sfcgal_geometry_t *geom, double s)
+    -> sfcgal_geometry_t *
+{
+  SFCGAL_GEOMETRY_CONVERT_CATCH_TO_ERROR(
+      const SFCGAL::Geometry &g =
+          *reinterpret_cast<const SFCGAL::Geometry *>(geom);
+      std::unique_ptr<SFCGAL::Geometry> result(g.clone());
+      SFCGAL::algorithm::scale(*result, s); return result.release();)
+}
+
+extern "C" auto
+sfcgal_geometry_scale_3d(const sfcgal_geometry_t *geom, double sx, double sy,
+                         double sz) -> sfcgal_geometry_t *
+{
+  SFCGAL_GEOMETRY_CONVERT_CATCH_TO_ERROR(
+      const SFCGAL::Geometry &g =
+          *reinterpret_cast<const SFCGAL::Geometry *>(geom);
+      std::unique_ptr<SFCGAL::Geometry> result(g.clone());
+      SFCGAL::algorithm::scale(*result, sx, sy, sz); return result.release();)
+}
+
+extern "C" auto
+sfcgal_geometry_scale_3d_around_center(const sfcgal_geometry_t *geom, double sx,
+                                       double sy, double sz, double cx,
+                                       double cy, double cz)
+    -> sfcgal_geometry_t *
+{
+  SFCGAL_GEOMETRY_CONVERT_CATCH_TO_ERROR(
+      const SFCGAL::Geometry &g =
+          *reinterpret_cast<const SFCGAL::Geometry *>(geom);
+      std::unique_ptr<SFCGAL::Geometry> result(g.clone());
+      SFCGAL::algorithm::scale(*result, sx, sy, sz, cx, cy, cz);
+      return result.release();)
+}
+
+extern "C" auto
+sfcgal_geometry_rotate(const sfcgal_geometry_t *geom, double angle)
+    -> sfcgal_geometry_t *
+{
+  SFCGAL_GEOMETRY_CONVERT_CATCH_TO_ERROR(
+      const SFCGAL::Geometry &g =
+          *reinterpret_cast<const SFCGAL::Geometry *>(geom);
+      std::unique_ptr<SFCGAL::Geometry> result(g.clone());
+      SFCGAL::algorithm::rotate(*result, angle); return result.release();)
+}
+
+extern "C" auto
+sfcgal_geometry_rotate_2d(const sfcgal_geometry_t *geom, double angle,
+                          double cx, double cy) -> sfcgal_geometry_t *
+{
+  SFCGAL_GEOMETRY_CONVERT_CATCH_TO_ERROR(
+      const SFCGAL::Geometry &g =
+          *reinterpret_cast<const SFCGAL::Geometry *>(geom);
+      std::unique_ptr<SFCGAL::Geometry> result(g.clone());
+      SFCGAL::algorithm::rotate(*result, angle, SFCGAL::Point(cx, cy));
+      return result.release();)
+}
+
+extern "C" auto
+sfcgal_geometry_rotate_3d(const sfcgal_geometry_t *geom, double angle,
+                          double ax, double ay, double az)
+    -> sfcgal_geometry_t *
+{
+  SFCGAL_GEOMETRY_CONVERT_CATCH_TO_ERROR(
+      const SFCGAL::Geometry &g =
+          *reinterpret_cast<const SFCGAL::Geometry *>(geom);
+      std::unique_ptr<SFCGAL::Geometry> result(g.clone());
+      SFCGAL::algorithm::rotate(*result, angle,
+                                SFCGAL::Kernel::Vector_3(ax, ay, az));
+      return result.release();)
+}
+
+extern "C" auto
+sfcgal_geometry_rotate_3d_around_center(const sfcgal_geometry_t *geom,
+                                        double angle, double ax, double ay,
+                                        double az, double cx, double cy,
+                                        double cz) -> sfcgal_geometry_t *
+{
+  SFCGAL_GEOMETRY_CONVERT_CATCH_TO_ERROR(
+      const SFCGAL::Geometry &g =
+          *reinterpret_cast<const SFCGAL::Geometry *>(geom);
+      std::unique_ptr<SFCGAL::Geometry> result(g.clone());
+      SFCGAL::algorithm::rotate(*result, angle,
+                                SFCGAL::Kernel::Vector_3(ax, ay, az),
+                                SFCGAL::Point(cx, cy, cz));
+      return result.release();)
+}
+
+extern "C" auto
+sfcgal_geometry_rotate_x(const sfcgal_geometry_t *geom, double angle)
+    -> sfcgal_geometry_t *
+{
+  SFCGAL_GEOMETRY_CONVERT_CATCH_TO_ERROR(
+      const SFCGAL::Geometry &g =
+          *reinterpret_cast<const SFCGAL::Geometry *>(geom);
+      std::unique_ptr<SFCGAL::Geometry> result(g.clone());
+      SFCGAL::algorithm::rotateX(*result, angle); return result.release();)
+}
+
+extern "C" auto
+sfcgal_geometry_rotate_y(const sfcgal_geometry_t *geom, double angle)
+    -> sfcgal_geometry_t *
+{
+  SFCGAL_GEOMETRY_CONVERT_CATCH_TO_ERROR(
+      const SFCGAL::Geometry &g =
+          *reinterpret_cast<const SFCGAL::Geometry *>(geom);
+      std::unique_ptr<SFCGAL::Geometry> result(g.clone());
+      SFCGAL::algorithm::rotateY(*result, angle); return result.release();)
+}
+
+extern "C" auto
+sfcgal_geometry_rotate_z(const sfcgal_geometry_t *geom, double angle)
+    -> sfcgal_geometry_t *
+{
+  SFCGAL_GEOMETRY_CONVERT_CATCH_TO_ERROR(
+      const SFCGAL::Geometry &g =
+          *reinterpret_cast<const SFCGAL::Geometry *>(geom);
+      std::unique_ptr<SFCGAL::Geometry> result(g.clone());
+      SFCGAL::algorithm::rotateZ(*result, angle); return result.release();)
+}
+
+extern "C" auto
+sfcgal_geometry_straight_skeleton_partition(const sfcgal_geometry_t *geom,
+                                            bool autoOrientation)
+    -> sfcgal_geometry_t *
+{
+  std::unique_ptr<SFCGAL::Geometry> result;
+  try {
+    result = SFCGAL::algorithm::straightSkeletonPartition(
+        *(const SFCGAL::Geometry *)(geom));
+  } catch (std::exception &e) {
+    SFCGAL_WARNING("During straight_skeleton_partition (A, %g) :",
+                   static_cast<int>(autoOrientation));
+    SFCGAL_WARNING("  with A: %s",
+                   ((const SFCGAL::Geometry *)(geom))->asText().c_str());
+    SFCGAL_ERROR("%s", e.what());
+    return nullptr;
+  }
+  return result.release();
+}
+
+extern "C" auto
+sfcgal_geometry_buffer3d(const sfcgal_geometry_t *geom, double radius,
+                         int segments, sfcgal_buffer3d_type_t buffer_type)
+    -> sfcgal_geometry_t *
+{
+  std::unique_ptr<SFCGAL::Geometry> result;
+  try {
+    SFCGAL::algorithm::Buffer3D::BufferType type;
+
+    switch (buffer_type) {
+    case SFCGAL_BUFFER3D_ROUND:
+      type = SFCGAL::algorithm::Buffer3D::ROUND;
+      break;
+    case SFCGAL_BUFFER3D_CYLSPHERE:
+      type = SFCGAL::algorithm::Buffer3D::CYLSPHERE;
+      break;
+    case SFCGAL_BUFFER3D_FLAT:
+      type = SFCGAL::algorithm::Buffer3D::FLAT;
+      break;
+    default:
+      SFCGAL_ERROR("Invalid buffer type");
+      return nullptr;
+    }
+
+    SFCGAL::algorithm::Buffer3D buffer3d(*(const SFCGAL::Geometry *)(geom),
+                                         radius, segments);
+    result = buffer3d.compute(type);
+  } catch (std::exception &e) {
+    SFCGAL_WARNING("During buffer3d (A, %g, %d, %d) :", radius, segments,
+                   buffer_type);
+    SFCGAL_WARNING("  with A: %s",
+                   ((const SFCGAL::Geometry *)(geom))->asText().c_str());
+    SFCGAL_ERROR("%s", e.what());
+    return nullptr;
+  }
+  return result.release();
+}
