@@ -2,12 +2,12 @@
 // Copyright (c) 2012-2022, Oslandia.
 // SPDX-License-Identifier: LGPL-2.0-or-later
 
-#ifndef _SFCGAL_DETAIL_GETPOINTSVISITOR_H_
-#define _SFCGAL_DETAIL_GETPOINTSVISITOR_H_
+#ifndef SFCGAL_DETAIL_GETPOINTSVISITOR_H_
+#define SFCGAL_DETAIL_GETPOINTSVISITOR_H_
 
-#include <SFCGAL/config.h>
+#include "SFCGAL/config.h"
 
-#include <SFCGAL/GeometryVisitor.h>
+#include "SFCGAL/GeometryVisitor.h"
 #include <vector>
 
 namespace SFCGAL {
