@@ -2,12 +2,12 @@
 // Copyright (c) 2012-2022, Oslandia.
 // SPDX-License-Identifier: LGPL-2.0-or-later
 
-#include <SFCGAL/Geometry.h>
-#include <SFCGAL/Point.h>
-#include <SFCGAL/algorithm/intersects.h>
-#include <SFCGAL/detail/GeometrySet.h>
-#include <SFCGAL/detail/GetPointsVisitor.h>
-#include <SFCGAL/detail/algorithm/coversPoints.h>
+#include "SFCGAL/detail/algorithm/coversPoints.h"
+#include "SFCGAL/Geometry.h"
+#include "SFCGAL/Point.h"
+#include "SFCGAL/algorithm/intersects.h"
+#include "SFCGAL/detail/GeometrySet.h"
+#include "SFCGAL/detail/GetPointsVisitor.h"
 
 namespace SFCGAL::detail::algorithm {
 template <int Dim>
