@@ -2,14 +2,14 @@
 // Copyright (c) 2012-2022, Oslandia.
 // SPDX-License-Identifier: LGPL-2.0-or-later
 
-#ifndef _SFCGAL_GENERATOR_BUILDING_H_
-#define _SFCGAL_GENERATOR_BUILDING_H_
+#ifndef SFCGAL_GENERATOR_BUILDING_H_
+#define SFCGAL_GENERATOR_BUILDING_H_
 
-#include <SFCGAL/config.h>
+#include "SFCGAL/config.h"
 
 #include <memory>
 
-#include <SFCGAL/Kernel.h>
+#include "SFCGAL/Kernel.h"
 
 namespace SFCGAL {
 class Geometry;
