@@ -1,15 +1,15 @@
 // Copyright (c) 2012-2013, IGN France.
 // Copyright (c) 2012-2022, Oslandia.
-// SPDX-License-Identifier: GPL-2.0-or-later
+// SPDX-License-Identifier: LGPL-2.0-or-later
 
-#ifndef _SFCGAL_SERIALIZATION_
-#define _SFCGAL_SERIALIZATION_
+#ifndef SFCGAL_SERIALIZATION_
+#define SFCGAL_SERIALIZATION_
 
-#include <SFCGAL/config.h>
+#include "SFCGAL/config.h"
 
-#include <SFCGAL/Geometry.h>
-#include <SFCGAL/Kernel.h>
-#include <SFCGAL/PreparedGeometry.h>
+#include "SFCGAL/Geometry.h"
+#include "SFCGAL/Kernel.h"
+#include "SFCGAL/PreparedGeometry.h"
 
 #include <boost/archive/binary_iarchive.hpp>
 #include <boost/archive/binary_oarchive.hpp>
