@@ -43,7 +43,7 @@ writeFT(std::ostream &s, const mpq_class &ft) -> std::ostream &
 ///
 ///
 ///
-WktWriter::WktWriter(std::ostream &s) : _s(s), _exactWrite(false) {}
+WktWriter::WktWriter(std::ostream &s) : _s(s) {}
 
 void
 WktWriter::writeRec(const Geometry &g)
@@ -120,11 +120,11 @@ void
 WktWriter::writeCoordinateType(const Geometry &g)
 {
   if (g.is3D() && !g.isMeasured()) {
-    _s << " Z";
+    _s << "Z ";
   } else if (!g.is3D() && g.isMeasured()) {
-    _s << " M";
+    _s << "M ";
   } else if (g.is3D() && g.isMeasured()) {
-    _s << " ZM";
+    _s << "ZM ";
   }
 }
 
@@ -172,11 +172,11 @@ WktWriter::writeCoordinate(const Point &g)
 void
 WktWriter::write(const Point &g)
 {
-  _s << "POINT";
+  _s << "POINT ";
   writeCoordinateType(g);
 
   if (g.isEmpty()) {
-    _s << " EMPTY";
+    _s << "EMPTY";
     return;
   }
 
@@ -205,11 +205,11 @@ WktWriter::writeInner(const Point &g)
 void
 WktWriter::write(const LineString &g)
 {
-  _s << "LINESTRING";
+  _s << "LINESTRING ";
   writeCoordinateType(g);
 
   if (g.isEmpty()) {
-    _s << " EMPTY";
+    _s << "EMPTY";
     return;
   }
 
@@ -241,11 +241,11 @@ WktWriter::writeInner(const LineString &g)
 void
 WktWriter::write(const Polygon &g)
 {
-  _s << "POLYGON";
+  _s << "POLYGON ";
   writeCoordinateType(g);
 
   if (g.isEmpty()) {
-    _s << " EMPTY";
+    _s << "EMPTY";
     return;
   }
 
@@ -275,11 +275,11 @@ WktWriter::writeInner(const Polygon &g)
 void
 WktWriter::write(const GeometryCollection &g)
 {
-  _s << "GEOMETRYCOLLECTION";
+  _s << "GEOMETRYCOLLECTION ";
   writeCoordinateType(g);
 
   if (g.isEmpty()) {
-    _s << " EMPTY";
+    _s << "EMPTY";
     return;
   }
 
@@ -302,11 +302,11 @@ WktWriter::write(const GeometryCollection &g)
 void
 WktWriter::write(const MultiPoint &g)
 {
-  _s << "MULTIPOINT";
+  _s << "MULTIPOINT ";
   writeCoordinateType(g);
 
   if (g.isEmpty()) {
-    _s << " EMPTY";
+    _s << "EMPTY";
     return;
   }
 
@@ -329,11 +329,11 @@ WktWriter::write(const MultiPoint &g)
 void
 WktWriter::write(const MultiLineString &g)
 {
-  _s << "MULTILINESTRING";
+  _s << "MULTILINESTRING ";
   writeCoordinateType(g);
 
   if (g.isEmpty()) {
-    _s << " EMPTY";
+    _s << "EMPTY";
     return;
   }
 
@@ -356,11 +356,11 @@ WktWriter::write(const MultiLineString &g)
 void
 WktWriter::write(const MultiPolygon &g)
 {
-  _s << "MULTIPOLYGON";
+  _s << "MULTIPOLYGON ";
   writeCoordinateType(g);
 
   if (g.isEmpty()) {
-    _s << " EMPTY";
+    _s << "EMPTY";
     return;
   }
 
@@ -383,11 +383,11 @@ WktWriter::write(const MultiPolygon &g)
 void
 WktWriter::write(const MultiSolid &g)
 {
-  _s << "MULTISOLID";
+  _s << "MULTISOLID ";
   writeCoordinateType(g);
 
   if (g.isEmpty()) {
-    _s << " EMPTY";
+    _s << "EMPTY";
     return;
   }
 
@@ -410,11 +410,11 @@ WktWriter::write(const MultiSolid &g)
 void
 WktWriter::write(const Triangle &g)
 {
-  _s << "TRIANGLE";
+  _s << "TRIANGLE ";
   writeCoordinateType(g);
 
   if (g.isEmpty()) {
-    _s << " EMPTY";
+    _s << "EMPTY";
     return;
   }
 
@@ -449,11 +449,11 @@ WktWriter::writeInner(const Triangle &g)
 void
 WktWriter::write(const TriangulatedSurface &g)
 {
-  _s << "TIN";
+  _s << "TIN ";
   writeCoordinateType(g);
 
   if (g.isEmpty()) {
-    _s << " EMPTY";
+    _s << "EMPTY";
     return;
   }
 
@@ -476,11 +476,11 @@ WktWriter::write(const TriangulatedSurface &g)
 void
 WktWriter::write(const PolyhedralSurface &g)
 {
-  _s << "POLYHEDRALSURFACE";
+  _s << "POLYHEDRALSURFACE ";
   writeCoordinateType(g);
 
   if (g.isEmpty()) {
-    _s << " EMPTY";
+    _s << "EMPTY";
     return;
   }
 
@@ -512,11 +512,11 @@ WktWriter::writeInner(const PolyhedralSurface &g)
 void
 WktWriter::write(const Solid &g)
 {
-  _s << "SOLID";
+  _s << "SOLID ";
   writeCoordinateType(g);
 
   if (g.isEmpty()) {
-    _s << " EMPTY";
+    _s << "EMPTY";
     return;
   }
 
