@@ -2,12 +2,12 @@
 // Copyright (c) 2012-2022, Oslandia.
 // SPDX-License-Identifier: LGPL-2.0-or-later
 
-#ifndef _SFCGAL_TRANSFORM_AFFINETRANSFORM2_H_
-#define _SFCGAL_TRANSFORM_AFFINETRANSFORM2_H_
+#ifndef SFCGAL_TRANSFORM_AFFINETRANSFORM2_H_
+#define SFCGAL_TRANSFORM_AFFINETRANSFORM2_H_
 
-#include <SFCGAL/Kernel.h>
-#include <SFCGAL/Transform.h>
-#include <SFCGAL/config.h>
+#include "SFCGAL/Kernel.h"
+#include "SFCGAL/Transform.h"
+#include "SFCGAL/config.h"
 
 #include <CGAL/Aff_transformation_2.h>
 
