@@ -2,8 +2,8 @@
 // Copyright (c) 2012-2022, Oslandia.
 // SPDX-License-Identifier: LGPL-2.0-or-later
 
-#include <SFCGAL/Point.h>
-#include <SFCGAL/detail/transform/ForceZ.h>
+#include "SFCGAL/detail/transform/ForceZ.h"
+#include "SFCGAL/Point.h"
 
 #include <utility>
 
@@ -12,7 +12,7 @@ namespace SFCGAL::transform {
 ///
 ///
 ///
-ForceZ::ForceZ(Kernel::FT defaultZ) : _defaultZ(defaultZ) {}
+ForceZ::ForceZ(Kernel::FT defaultZ) : _defaultZ(std::move(defaultZ)) {}
 
 ///
 ///
