@@ -1,14 +1,14 @@
 // Copyright (c) 2012-2013, IGN France.
 // Copyright (c) 2012-2022, Oslandia.
-// SPDX-License-Identifier: GPL-2.0-or-later
+// SPDX-License-Identifier: LGPL-2.0-or-later
 
-#ifndef _SFCGAL_TRANSFORM_FORCEZ_H_
-#define _SFCGAL_TRANSFORM_FORCEZ_H_
+#ifndef SFCGAL_TRANSFORM_FORCEZ_H_
+#define SFCGAL_TRANSFORM_FORCEZ_H_
 
-#include <SFCGAL/config.h>
+#include "SFCGAL/config.h"
 
-#include <SFCGAL/Kernel.h>
-#include <SFCGAL/Transform.h>
+#include "SFCGAL/Kernel.h"
+#include "SFCGAL/Transform.h"
 
 namespace SFCGAL {
 namespace transform {
