@@ -2,11 +2,11 @@
 // Copyright (c) 2012-2022, Oslandia.
 // SPDX-License-Identifier: LGPL-2.0-or-later
 
-#include <SFCGAL/Point.h>
-#include <SFCGAL/Polygon.h>
-#include <SFCGAL/Triangle.h>
-#include <SFCGAL/algorithm/orientation.h>
-#include <SFCGAL/detail/transform/ForceZOrderPoints.h>
+#include "SFCGAL/detail/transform/ForceZOrderPoints.h"
+#include "SFCGAL/Point.h"
+#include "SFCGAL/Polygon.h"
+#include "SFCGAL/Triangle.h"
+#include "SFCGAL/algorithm/orientation.h"
 
 #include <utility>
 
@@ -15,7 +15,8 @@ namespace SFCGAL::transform {
 ///
 ///
 ///
-ForceZOrderPoints::ForceZOrderPoints(Kernel::FT defaultZ) : _defaultZ(defaultZ)
+ForceZOrderPoints::ForceZOrderPoints(Kernel::FT defaultZ)
+    : _defaultZ(std::move(defaultZ))
 {
 }
 
