@@ -2,9 +2,9 @@
 // Copyright (c) 2012-2022, Oslandia.
 // SPDX-License-Identifier: LGPL-2.0-or-later
 
-#include <SFCGAL/detail/transform/RoundTransform.h>
+#include "SFCGAL/detail/transform/RoundTransform.h"
 
-#include <SFCGAL/Point.h>
+#include "SFCGAL/Point.h"
 
 namespace SFCGAL::transform {
 
