@@ -2,8 +2,8 @@
 // Copyright (c) 2012-2022, Oslandia.
 // SPDX-License-Identifier: LGPL-2.0-or-later
 
-#ifndef _SFCGAL_TRIANGULATE_IN_GEOMETRY_SET_H_
-#define _SFCGAL_TRIANGULATE_IN_GEOMETRY_SET_H_
+#ifndef SFCGAL_TRIANGULATE_IN_GEOMETRY_SET_H_
+#define SFCGAL_TRIANGULATE_IN_GEOMETRY_SET_H_
 
 #include "SFCGAL/config.h"
 
