@@ -1,9 +1,9 @@
 // Copyright (c) 2012-2013, IGN France.
 // Copyright (c) 2012-2022, Oslandia.
-// SPDX-License-Identifier: GPL-2.0-or-later
+// SPDX-License-Identifier: LGPL-2.0-or-later
 
-#ifndef _SFCGAL_UBLAS_H_
-#define _SFCGAL_UBLAS_H_
+#ifndef SFCGAL_UBLAS_H_
+#define SFCGAL_UBLAS_H_
 
 #include <boost/numeric/ublas/matrix.hpp>
 #include <boost/numeric/ublas/vector.hpp>
