@@ -2,10 +2,10 @@
 // Copyright (c) 2012-2022, Oslandia.
 // SPDX-License-Identifier: LGPL-2.0-or-later
 
-#ifndef _SFCGAL_IO_EWKT_H_
-#define _SFCGAL_IO_EWKT_H_
+#ifndef SFCGAL_IO_EWKT_H_
+#define SFCGAL_IO_EWKT_H_
 
-#include <SFCGAL/config.h>
+#include "SFCGAL/config.h"
 
 #include <memory>
 #include <sstream>
