@@ -18,20 +18,20 @@
  *   License along with this library; if not, see
  <http://www.gnu.org/licenses/>.
  */
-#include <SFCGAL/GeometryCollection.h>
-#include <SFCGAL/LineString.h>
-#include <SFCGAL/MultiLineString.h>
-#include <SFCGAL/MultiPoint.h>
-#include <SFCGAL/MultiPolygon.h>
-#include <SFCGAL/MultiSolid.h>
-#include <SFCGAL/Point.h>
-#include <SFCGAL/Polygon.h>
-#include <SFCGAL/PolyhedralSurface.h>
-#include <SFCGAL/Solid.h>
-#include <SFCGAL/Triangle.h>
-#include <SFCGAL/TriangulatedSurface.h>
-#include <SFCGAL/algorithm/minkowskiSum.h>
-#include <SFCGAL/io/wkt.h>
+#include "SFCGAL/GeometryCollection.h"
+#include "SFCGAL/LineString.h"
+#include "SFCGAL/MultiLineString.h"
+#include "SFCGAL/MultiPoint.h"
+#include "SFCGAL/MultiPolygon.h"
+#include "SFCGAL/MultiSolid.h"
+#include "SFCGAL/Point.h"
+#include "SFCGAL/Polygon.h"
+#include "SFCGAL/PolyhedralSurface.h"
+#include "SFCGAL/Solid.h"
+#include "SFCGAL/Triangle.h"
+#include "SFCGAL/TriangulatedSurface.h"
+#include "SFCGAL/algorithm/minkowskiSum.h"
+#include "SFCGAL/io/wkt.h"
 
 #include "../test_config.h"
 #include "Bench.h"
@@ -46,7 +46,7 @@ BOOST_AUTO_TEST_SUITE(SFCGAL_BenchMinkowskiSum)
 BOOST_AUTO_TEST_CASE(testPolygonWithHoles)
 {
   std::unique_ptr<Geometry> gA(io::readWkt(
-      "MULTIPOLYGON(((11.795461 32.713032,11.381695 35.857648,15.188336 "
+      "MULTIPOLYGON (((11.795461 32.713032,11.381695 35.857648,15.188336 "
       "38.091981,28.428825 38.257487,30.994170 33.788822,30.580405 "
       "29.816675,26.773764 22.617159,11.050683 18.562259,-0.534745 "
       "21.044851,-3.513855 26.837565,3.520155 26.506553,4.099426 "
@@ -64,7 +64,7 @@ BOOST_AUTO_TEST_CASE(testPolygonWithHoles)
       "36.271413,14.609065 28.161614,15.022830 27.582342,20.401779 "
       "29.816675,29.339109 32.133760,21.477568 36.188660)))"));
   std::unique_ptr<Geometry> gB(
-      io::readWkt("POLYGON((-1 0,0 -1,1 0,0 1,-1 0))"));
+      io::readWkt("POLYGON ((-1 0,0 -1,1 0,0 1,-1 0))"));
 
   bench().start("minkowski polygon with hole");
 
@@ -80,7 +80,8 @@ BOOST_AUTO_TEST_SUITE_END()
 
 // BOOST_AUTO_TEST_CASE( testTemp ){
 //	std::unique_ptr< Geometry > gA(
-// io::readWkt("MULTIPOLYGON(((11.795461 32.713032,11.381695 35.857648,15.188336 38.091981,28.428825
+// io::readWkt("MULTIPOLYGON
+// (((11.795461 32.713032,11.381695 35.857648,15.188336 38.091981,28.428825
 // 38.257487,30.994170 33.788822,30.580405 29.816675,26.773764 22.617159,11.050683
 // 18.562259,-0.534745 21.044851,-3.513855 26.837565,3.520155 26.506553,4.099426 24.685985,4.678698
 // 22.782665,6.582018 21.541369,8.899104 21.458616,16.098620 21.706875,18.332952 25.016998,17.919187
@@ -92,7 +93,7 @@ BOOST_AUTO_TEST_SUITE_END()
 // 33.126797,13.450522 34.119834,11.795461 32.713032),(21.477568 36.188660,15.684854
 // 36.271413,14.609065 28.161614,15.022830 27.582342,20.401779 29.816675,29.339109
 // 32.133760,21.477568 36.188660)))") ); 	std::unique_ptr< Geometry > gB(
-// io::readWkt( "POLYGON((-1 0,0 -1,1 0,0 1,-1 0))" ) );
+// io::readWkt( "POLYGON ((-1 0,0 -1,1 0,0 1,-1 0))" ) );
 //
 //	std::unique_ptr< Geometry > sum( algorithm::minkowskiSum( *gA, gB->as<
 // Polygon >() ) ); 	std::cout << sum->asText(6) << std::endl ;
