@@ -18,9 +18,9 @@
  *   License along with this library; if not, see
  <http://www.gnu.org/licenses/>.
  */
-#include <SFCGAL/Geometry.h>
-#include <SFCGAL/algorithm/intersection.h>
-#include <SFCGAL/io/wkt.h>
+#include "SFCGAL/Geometry.h"
+#include "SFCGAL/algorithm/intersection.h"
+#include "SFCGAL/io/wkt.h"
 
 #include "../../../test_config.h"
 
