@@ -20,24 +20,24 @@
  */
 #include <boost/test/unit_test.hpp>
 
-#include <SFCGAL/GeometryCollection.h>
-#include <SFCGAL/Kernel.h>
-#include <SFCGAL/LineString.h>
-#include <SFCGAL/MultiLineString.h>
-#include <SFCGAL/MultiPoint.h>
-#include <SFCGAL/MultiPolygon.h>
-#include <SFCGAL/MultiSolid.h>
-#include <SFCGAL/Point.h>
-#include <SFCGAL/Polygon.h>
-#include <SFCGAL/PolyhedralSurface.h>
-#include <SFCGAL/Solid.h>
-#include <SFCGAL/Triangle.h>
-#include <SFCGAL/TriangulatedSurface.h>
-#include <SFCGAL/algorithm/covers.h>
-#include <SFCGAL/algorithm/straightSkeleton.h>
-#include <SFCGAL/io/wkt.h>
+#include "SFCGAL/GeometryCollection.h"
+#include "SFCGAL/Kernel.h"
+#include "SFCGAL/LineString.h"
+#include "SFCGAL/MultiLineString.h"
+#include "SFCGAL/MultiPoint.h"
+#include "SFCGAL/MultiPolygon.h"
+#include "SFCGAL/MultiSolid.h"
+#include "SFCGAL/Point.h"
+#include "SFCGAL/Polygon.h"
+#include "SFCGAL/PolyhedralSurface.h"
+#include "SFCGAL/Solid.h"
+#include "SFCGAL/Triangle.h"
+#include "SFCGAL/TriangulatedSurface.h"
+#include "SFCGAL/algorithm/covers.h"
+#include "SFCGAL/algorithm/straightSkeleton.h"
+#include "SFCGAL/io/wkt.h"
 
-#include <SFCGAL/detail/tools/Registry.h>
+#include "SFCGAL/detail/tools/Registry.h"
 
 using namespace boost::unit_test;
 using namespace SFCGAL;
@@ -46,10 +46,11 @@ BOOST_AUTO_TEST_SUITE(SFCGAL_algorithm_ApproximateMedialAxisTest)
 
 BOOST_AUTO_TEST_CASE(testTriangle45)
 {
-  std::unique_ptr<Geometry> const g(io::readWkt("TRIANGLE((1 1,2 1,2 2,1 1))"));
+  std::unique_ptr<Geometry> const g(
+      io::readWkt("TRIANGLE ((1 1,2 1,2 2,1 1))"));
 
   std::string const expectedWKT(
-      "MULTILINESTRING((1.0 1.0,1.7 1.3),(2.0 2.0,1.7 1.3))");
+      "MULTILINESTRING ((1.0 1.0,1.7 1.3),(2.0 2.0,1.7 1.3))");
   {
     std::unique_ptr<MultiLineString> result(
         algorithm::approximateMedialAxis(*g));
@@ -59,7 +60,8 @@ BOOST_AUTO_TEST_CASE(testTriangle45)
 
 BOOST_AUTO_TEST_CASE(testTriangle60)
 {
-  std::unique_ptr<Geometry> const g(io::readWkt("TRIANGLE((1 1,3 1,2 3,1 1))"));
+  std::unique_ptr<Geometry> const g(
+      io::readWkt("TRIANGLE ((1 1,3 1,2 3,1 1))"));
 
   std::string const expectedWKT("MULTILINESTRING EMPTY");
   {
@@ -73,9 +75,9 @@ BOOST_AUTO_TEST_CASE(testTriangle60)
 BOOST_AUTO_TEST_CASE(testPolygon)
 {
   std::unique_ptr<Geometry> const g(
-      io::readWkt("POLYGON((0 0,20 0,20 10,0 10,0 0))"));
+      io::readWkt("POLYGON ((0 0,20 0,20 10,0 10,0 0))"));
 
-  std::string const expectedWKT("MULTILINESTRING((5 5,15 5))");
+  std::string const expectedWKT("MULTILINESTRING ((5 5,15 5))");
   {
     std::unique_ptr<MultiLineString> result(
         algorithm::approximateMedialAxis(*g));
@@ -87,7 +89,7 @@ BOOST_AUTO_TEST_CASE(testPolygon)
 BOOST_AUTO_TEST_CASE(testPolygonWithHole)
 {
   std::unique_ptr<Geometry> const g(
-      io::readWkt("POLYGON( (0 0,10 0,10 10,0 10,0 0)"
+      io::readWkt("POLYGON ( (0 0,10 0,10 10,0 10,0 0)"
                   ", (4 4,4 6,6 6,6 4,4 4)"
                   ")"));
 
@@ -95,7 +97,7 @@ BOOST_AUTO_TEST_CASE(testPolygonWithHole)
   BOOST_CHECK_EQUAL(result->numGeometries(), 4);
 
   std::unique_ptr<Geometry> const expected(
-      io::readWkt("MULTILINESTRING( (2 2,8 2)"
+      io::readWkt("MULTILINESTRING ( (2 2,8 2)"
                   ", (2 2,2 8)"
                   ", (8 2,8 8)"
                   ", (2 8,8 8)"
@@ -107,7 +109,7 @@ BOOST_AUTO_TEST_CASE(testPolygonWithHole)
 BOOST_AUTO_TEST_CASE(testPolygonWithTouchingHoles)
 {
   std::unique_ptr<Geometry> const g(
-      io::readWkt("POLYGON((-1.0 -1.0,1.0 -1.0,1.0 1.0,-1.0 1.0,-1.0 "
+      io::readWkt("POLYGON ((-1.0 -1.0,1.0 -1.0,1.0 1.0,-1.0 1.0,-1.0 "
                   "-1.0),(-0.5 -0.5,-0.5 0.5,-0.1 0.5,0.1 -0.5,-0.5 -0.5),(0.1 "
                   "-0.5,0.1 0.5,0.5 0.5,0.5 -0.5,0.1 -0.5))"));
 
@@ -120,7 +122,7 @@ BOOST_AUTO_TEST_CASE(testPolygonWithTouchingHoles)
 BOOST_AUTO_TEST_CASE(testMultiPolygon)
 {
   std::unique_ptr<Geometry> const  g(io::readWkt(
-      "MULTIPOLYGON(((3.000000 0.000000,2.875000 0.484123,2.750000 "
+      "MULTIPOLYGON (((3.000000 0.000000,2.875000 0.484123,2.750000 "
        "0.661438,2.625000 0.780625,2.500000 0.866025,2.375000 0.927025,2.250000 "
        "0.968246,2.125000 0.992157,2.000000 1.000000,1.875000 1.484123,1.750000 "
        "1.661438,1.625000 1.780625,1.500000 1.866025,1.375000 1.927025,1.250000 "
@@ -163,8 +165,8 @@ BOOST_AUTO_TEST_CASE(testMultiPolygon)
 BOOST_AUTO_TEST_CASE(testInvalidTypes)
 {
   std::vector<std::string> wkt;
-  wkt.emplace_back("POINT(1 2)");
-  wkt.emplace_back("LINESTRING(0 0,1 1)");
+  wkt.emplace_back("POINT (1 2)");
+  wkt.emplace_back("LINESTRING (0 0,1 1)");
 
   for (auto &it : wkt) {
     std::unique_ptr<Geometry> const  g(io::readWkt(it));
