@@ -20,23 +20,23 @@
  */
 #include <boost/test/unit_test.hpp>
 
-#include <SFCGAL/GeometryCollection.h>
-#include <SFCGAL/LineString.h>
-#include <SFCGAL/MultiLineString.h>
-#include <SFCGAL/MultiPoint.h>
-#include <SFCGAL/MultiPolygon.h>
-#include <SFCGAL/MultiSolid.h>
-#include <SFCGAL/Point.h>
-#include <SFCGAL/Polygon.h>
-#include <SFCGAL/PolyhedralSurface.h>
-#include <SFCGAL/Solid.h>
-#include <SFCGAL/Triangle.h>
-#include <SFCGAL/TriangulatedSurface.h>
-#include <SFCGAL/algorithm/distance.h>
-#include <SFCGAL/io/wkt.h>
+#include "SFCGAL/GeometryCollection.h"
+#include "SFCGAL/LineString.h"
+#include "SFCGAL/MultiLineString.h"
+#include "SFCGAL/MultiPoint.h"
+#include "SFCGAL/MultiPolygon.h"
+#include "SFCGAL/MultiSolid.h"
+#include "SFCGAL/Point.h"
+#include "SFCGAL/Polygon.h"
+#include "SFCGAL/PolyhedralSurface.h"
+#include "SFCGAL/Solid.h"
+#include "SFCGAL/Triangle.h"
+#include "SFCGAL/TriangulatedSurface.h"
+#include "SFCGAL/algorithm/distance.h"
+#include "SFCGAL/io/wkt.h"
 
-#include <SFCGAL/detail/tools/Log.h>
-#include <SFCGAL/detail/tools/Registry.h>
+#include "SFCGAL/detail/tools/Log.h"
+#include "SFCGAL/detail/tools/Registry.h"
 
 using namespace SFCGAL;
 
@@ -159,34 +159,34 @@ BOOST_AUTO_TEST_CASE(testDistancePointLineString_pointOutOfLineString)
 // testPointPolygon
 BOOST_AUTO_TEST_CASE(testDistancePointPolygon_pointInPolygon)
 {
-  std::unique_ptr<Geometry>       gA(io::readWkt("POINT(0.5 0.5)"));
+  std::unique_ptr<Geometry>       gA(io::readWkt("POINT (0.5 0.5)"));
   std::unique_ptr<Geometry> const gB(
-      io::readWkt("POLYGON((0.0 0.0,1.0 0.0,1.0 1.0,0.0 1.0,0.0 0.0))"));
+      io::readWkt("POLYGON ((0.0 0.0,1.0 0.0,1.0 1.0,0.0 1.0,0.0 0.0))"));
   BOOST_CHECK_EQUAL(gA->distance(*gB), 0.0);
 }
 BOOST_AUTO_TEST_CASE(testDistancePointPolygon_pointOutOfPolygon)
 {
-  std::unique_ptr<Geometry>       gA(io::readWkt("POINT(0.0 1.0)"));
+  std::unique_ptr<Geometry>       gA(io::readWkt("POINT (0.0 1.0)"));
   std::unique_ptr<Geometry> const gB(
-      io::readWkt("POLYGON((0.0 0.0,2.0 2.0,2.0 0.0,0.0 0.0))"));
+      io::readWkt("POLYGON ((0.0 0.0,2.0 2.0,2.0 0.0,0.0 0.0))"));
   BOOST_CHECK_EQUAL(gA->distance(*gB), sqrt(2.0) / 2.0);
 }
 
 // LineString / LineString 2D
 BOOST_AUTO_TEST_CASE(testDistanceLineStringLineString_zeroLengthSegments)
 {
-  std::unique_ptr<Geometry> gA(io::readWkt("LINESTRING(0.0 0.0,-1.0 -1.0)"));
+  std::unique_ptr<Geometry> gA(io::readWkt("LINESTRING (0.0 0.0,-1.0 -1.0)"));
   std::unique_ptr<Geometry> const gB(
-      io::readWkt("LINESTRING(3.0 4.0,4.0 5.0)"));
+      io::readWkt("LINESTRING (3.0 4.0,4.0 5.0)"));
   BOOST_CHECK_EQUAL(gA->distance(*gB), 5.0);
 }
 // LineString / LineString 3D
 BOOST_AUTO_TEST_CASE(testDistanceLineStringLineString3D_zeroLengthSegments)
 {
   std::unique_ptr<Geometry> gA(
-      io::readWkt("LINESTRING(0.0 0.0 0.0,-1.0 -1.0 -1.0)"));
+      io::readWkt("LINESTRING (0.0 0.0 0.0,-1.0 -1.0 -1.0)"));
   std::unique_ptr<Geometry> const gB(
-      io::readWkt("LINESTRING(0.0 3.0 4.0,0.0 4.0 5.0)"));
+      io::readWkt("LINESTRING (0.0 3.0 4.0,0.0 4.0 5.0)"));
   BOOST_CHECK_EQUAL(gA->distance3D(*gB), 5.0);
 }
 
@@ -194,18 +194,18 @@ BOOST_AUTO_TEST_CASE(testDistanceLineStringLineString3D_zeroLengthSegments)
 BOOST_AUTO_TEST_CASE(testDistance3DLineStringTriangle_lineStringInTriangle)
 {
   std::unique_ptr<Geometry> gA(
-      io::readWkt("LINESTRING(-1.0 0.0 1.0,1.0 0.0 1.0)"));
+      io::readWkt("LINESTRING (-1.0 0.0 1.0,1.0 0.0 1.0)"));
   std::unique_ptr<Geometry> const gB(io::readWkt(
-      "TRIANGLE((-4.0 0.0 1.0,4.0 0.0 1.0,0.0 4.0 1.0,-4.0 0.0 1.0))"));
+      "TRIANGLE ((-4.0 0.0 1.0,4.0 0.0 1.0,0.0 4.0 1.0,-4.0 0.0 1.0))"));
   BOOST_CHECK_EQUAL(gA->distance3D(*gB), 0.0);
 }
 BOOST_AUTO_TEST_CASE(
     testDistance3DLineStringTriangle_lineStringStartPointIsNearest)
 {
   std::unique_ptr<Geometry> gA(
-      io::readWkt("LINESTRING(-1.0 0.0 2.0,1.0 0.0 3.0)"));
+      io::readWkt("LINESTRING (-1.0 0.0 2.0,1.0 0.0 3.0)"));
   std::unique_ptr<Geometry> const gB(io::readWkt(
-      "TRIANGLE((-4.0 0.0 1.0,4.0 0.0 1.0,0.0 4.0 1.0,-4.0 0.0 1.0))"));
+      "TRIANGLE ((-4.0 0.0 1.0,4.0 0.0 1.0,0.0 4.0 1.0,-4.0 0.0 1.0))"));
   BOOST_CHECK_EQUAL(gA->distance3D(*gB), 1.0);
 }
 
@@ -213,17 +213,17 @@ BOOST_AUTO_TEST_CASE(
 BOOST_AUTO_TEST_CASE(testDistance3DTriangleTriangle_contained)
 {
   std::unique_ptr<Geometry>       gA(io::readWkt(
-      "TRIANGLE((-3.0 0.0 1.0,3.0 0.0 1.0,0.0 3.0 1.0,-3.0 0.0 1.0))"));
+      "TRIANGLE ((-3.0 0.0 1.0,3.0 0.0 1.0,0.0 3.0 1.0,-3.0 0.0 1.0))"));
   std::unique_ptr<Geometry> const gB(io::readWkt(
-      "TRIANGLE((-4.0 0.0 1.0,4.0 0.0 1.0,0.0 4.0 1.0,-4.0 0.0 1.0))"));
+      "TRIANGLE ((-4.0 0.0 1.0,4.0 0.0 1.0,0.0 4.0 1.0,-4.0 0.0 1.0))"));
   BOOST_CHECK_EQUAL(gA->distance3D(*gB), 0.0);
 }
 BOOST_AUTO_TEST_CASE(testDistance3DTriangleTriangle_parallel)
 {
   std::unique_ptr<Geometry>       gA(io::readWkt(
-      "TRIANGLE((-3.0 0.0 1.0,3.0 0.0 1.0,0.0 3.0 1.0,-3.0 0.0 1.0))"));
+      "TRIANGLE ((-3.0 0.0 1.0,3.0 0.0 1.0,0.0 3.0 1.0,-3.0 0.0 1.0))"));
   std::unique_ptr<Geometry> const gB(io::readWkt(
-      "TRIANGLE((-4.0 0.0 2.0,4.0 0.0 2.0,0.0 4.0 2.0,-4.0 0.0 2.0))"));
+      "TRIANGLE ((-4.0 0.0 2.0,4.0 0.0 2.0,0.0 4.0 2.0,-4.0 0.0 2.0))"));
   BOOST_CHECK_EQUAL(gA->distance3D(*gB), 1.0);
 }
 
@@ -232,18 +232,18 @@ BOOST_AUTO_TEST_CASE(testDistance3DTriangleTriangle_parallel)
 BOOST_AUTO_TEST_CASE(testDistancePolygonPolygon_disjoint)
 {
   std::unique_ptr<Geometry> gA(
-      io::readWkt("POLYGON((0.0 0.0,1.0 0.0,1.0 1.0,0.0 1.0,0.0 0.0))"));
+      io::readWkt("POLYGON ((0.0 0.0,1.0 0.0,1.0 1.0,0.0 1.0,0.0 0.0))"));
   std::unique_ptr<Geometry> const gB(
-      io::readWkt("POLYGON((2.0 0.0,3.0 0.0,3.0 1.0,2.0 1.0,2.0 0.0))"));
+      io::readWkt("POLYGON ((2.0 0.0,3.0 0.0,3.0 1.0,2.0 1.0,2.0 0.0))"));
   BOOST_CHECK_EQUAL(gA->distance(*gB), 1.0);
 }
 
 BOOST_AUTO_TEST_CASE(testDistanceMultiPointMultiPoint_disjoint)
 {
   std::unique_ptr<Geometry> gA(
-      io::readWkt("MULTIPOINT((0.0 0.0),(1.0 0.0),(1.0 1.0),(0.0 1.0))"));
+      io::readWkt("MULTIPOINT ((0.0 0.0),(1.0 0.0),(1.0 1.0),(0.0 1.0))"));
   std::unique_ptr<Geometry> const gB(
-      io::readWkt("MULTIPOINT((8.0 8.0),(4.0 5.0))"));
+      io::readWkt("MULTIPOINT ((8.0 8.0),(4.0 5.0))"));
   BOOST_CHECK_EQUAL(gA->distance(*gB), 5.0);
 }
 
@@ -251,9 +251,9 @@ BOOST_AUTO_TEST_CASE(testDistanceMultiPointMultiPoint_disjoint)
 BOOST_AUTO_TEST_CASE(testDistancePolygonSolid)
 {
   std::unique_ptr<Geometry> gA(
-      io::readWkt("POLYGON((1 -1 -1,1 1 -1,1 1 1,1 -1 1,1 -1 -1))"));
+      io::readWkt("POLYGON ((1 -1 -1,1 1 -1,1 1 1,1 -1 1,1 -1 -1))"));
   std::unique_ptr<Geometry> const gB(
-      io::readWkt("SOLID((((0 0 0,0 1 0,1 1 0,1 0 0,0 0 0)),((0 0 0,0 0 1,0 1 "
+      io::readWkt("SOLID ((((0 0 0,0 1 0,1 1 0,1 0 0,0 0 0)),((0 0 0,0 0 1,0 1 "
                   "1,0 1 0,0 0 0)),((0 0 0,1 0 0,1 0 1,0 0 1,0 0 0)),((1 1 1,0 "
                   "1 1,0 0 1,1 0 1,1 1 1)),((1 1 1,1 0 1,1 0 0,1 1 0,1 1 "
                   "1)),((1 1 1,1 1 0,0 1 0,0 1 1,1 1 1))))"));
