@@ -20,23 +20,23 @@
  */
 #include <boost/test/unit_test.hpp>
 
-#include <SFCGAL/GeometryCollection.h>
-#include <SFCGAL/Kernel.h>
-#include <SFCGAL/LineString.h>
-#include <SFCGAL/MultiLineString.h>
-#include <SFCGAL/MultiPoint.h>
-#include <SFCGAL/MultiPolygon.h>
-#include <SFCGAL/MultiSolid.h>
-#include <SFCGAL/Point.h>
-#include <SFCGAL/Polygon.h>
-#include <SFCGAL/PolyhedralSurface.h>
-#include <SFCGAL/Solid.h>
-#include <SFCGAL/Triangle.h>
-#include <SFCGAL/TriangulatedSurface.h>
-#include <SFCGAL/algorithm/force3D.h>
-#include <SFCGAL/io/wkt.h>
+#include "SFCGAL/GeometryCollection.h"
+#include "SFCGAL/Kernel.h"
+#include "SFCGAL/LineString.h"
+#include "SFCGAL/MultiLineString.h"
+#include "SFCGAL/MultiPoint.h"
+#include "SFCGAL/MultiPolygon.h"
+#include "SFCGAL/MultiSolid.h"
+#include "SFCGAL/Point.h"
+#include "SFCGAL/Polygon.h"
+#include "SFCGAL/PolyhedralSurface.h"
+#include "SFCGAL/Solid.h"
+#include "SFCGAL/Triangle.h"
+#include "SFCGAL/TriangulatedSurface.h"
+#include "SFCGAL/algorithm/force3D.h"
+#include "SFCGAL/io/wkt.h"
 
-#include <SFCGAL/detail/tools/Registry.h>
+#include "SFCGAL/detail/tools/Registry.h"
 
 using namespace boost::unit_test;
 using namespace SFCGAL;
@@ -55,7 +55,7 @@ BOOST_AUTO_TEST_CASE(testIgnoreEmpty)
     BOOST_TEST_MESSAGE(typeName);
 
     std::unique_ptr<Geometry> g(registry.newGeometryByTypeName(typeName));
-    BOOST_REQUIRE(g.get() != NULL);
+    BOOST_REQUIRE(g.get() != nullptr);
     algorithm::force3D(*g);
     BOOST_CHECK(g->isEmpty());
   }
@@ -65,13 +65,13 @@ BOOST_AUTO_TEST_CASE(testPointForceZ)
 {
   Point p(3.0, 4.0);
   algorithm::force3D(p);
-  BOOST_CHECK_EQUAL(p.asText(1), "POINT Z(3.0 4.0 0.0)");
+  BOOST_CHECK_EQUAL(p.asText(1), "POINT Z (3.0 4.0 0.0)");
 }
 BOOST_AUTO_TEST_CASE(testPointForceZWithValue)
 {
   Point p(3.0, 4.0);
   algorithm::force3D(p, -9999.0);
-  BOOST_CHECK_EQUAL(p.asText(1), "POINT Z(3.0 4.0 -9999.0)");
+  BOOST_CHECK_EQUAL(p.asText(1), "POINT Z (3.0 4.0 -9999.0)");
 }
 
 BOOST_AUTO_TEST_CASE(test_MixedLineString2D3D)
@@ -83,7 +83,7 @@ BOOST_AUTO_TEST_CASE(test_MixedLineString2D3D)
   algorithm::force3D(lineString);
   // should keep 1.0 for the second point
   BOOST_CHECK_EQUAL(lineString.asText(1),
-                    "LINESTRING Z(1.0 1.0 0.0,2.0 2.0 1.0,3.0 3.0 0.0)");
+                    "LINESTRING Z (1.0 1.0 0.0,2.0 2.0 1.0,3.0 3.0 0.0)");
 }
 
 BOOST_AUTO_TEST_SUITE_END()
