@@ -20,24 +20,24 @@
  */
 #include <fstream>
 
-#include <SFCGAL/GeometryCollection.h>
-#include <SFCGAL/Kernel.h>
-#include <SFCGAL/LineString.h>
-#include <SFCGAL/MultiLineString.h>
-#include <SFCGAL/MultiPoint.h>
-#include <SFCGAL/MultiPolygon.h>
-#include <SFCGAL/MultiSolid.h>
-#include <SFCGAL/Point.h>
-#include <SFCGAL/Polygon.h>
-#include <SFCGAL/PolyhedralSurface.h>
-#include <SFCGAL/Solid.h>
-#include <SFCGAL/Triangle.h>
-#include <SFCGAL/TriangulatedSurface.h>
-#include <SFCGAL/algorithm/intersection.h>
-#include <SFCGAL/detail/GetPointsVisitor.h>
-#include <SFCGAL/detail/transform/AffineTransform3.h>
-#include <SFCGAL/io/GeometryStreams.h>
-#include <SFCGAL/io/wkt.h>
+#include "SFCGAL/GeometryCollection.h"
+#include "SFCGAL/Kernel.h"
+#include "SFCGAL/LineString.h"
+#include "SFCGAL/MultiLineString.h"
+#include "SFCGAL/MultiPoint.h"
+#include "SFCGAL/MultiPolygon.h"
+#include "SFCGAL/MultiSolid.h"
+#include "SFCGAL/Point.h"
+#include "SFCGAL/Polygon.h"
+#include "SFCGAL/PolyhedralSurface.h"
+#include "SFCGAL/Solid.h"
+#include "SFCGAL/Triangle.h"
+#include "SFCGAL/TriangulatedSurface.h"
+#include "SFCGAL/algorithm/intersection.h"
+#include "SFCGAL/detail/GetPointsVisitor.h"
+#include "SFCGAL/detail/transform/AffineTransform3.h"
+#include "SFCGAL/io/GeometryStreams.h"
+#include "SFCGAL/io/wkt.h"
 
 #include "../../../test_config.h"
 
@@ -114,7 +114,7 @@ BOOST_AUTO_TEST_CASE(testFileIntersectionTest)
     }
 
     if (print_line_number) {
-      std::cout << numLine << std::endl;
+      std::cout << numLine << '\n';
     }
 
     if (test_one_line == -1) {
