@@ -20,21 +20,21 @@
  */
 #include <boost/test/unit_test.hpp>
 
-#include <SFCGAL/GeometryCollection.h>
-#include <SFCGAL/LineString.h>
-#include <SFCGAL/MultiLineString.h>
-#include <SFCGAL/MultiPoint.h>
-#include <SFCGAL/MultiPolygon.h>
-#include <SFCGAL/MultiSolid.h>
-#include <SFCGAL/Point.h>
-#include <SFCGAL/Polygon.h>
-#include <SFCGAL/PolyhedralSurface.h>
-#include <SFCGAL/Solid.h>
-#include <SFCGAL/Triangle.h>
-#include <SFCGAL/TriangulatedSurface.h>
-#include <SFCGAL/algorithm/isValid.h>
-#include <SFCGAL/detail/TestGeometry.h>
-#include <SFCGAL/io/wkt.h>
+#include "SFCGAL/GeometryCollection.h"
+#include "SFCGAL/LineString.h"
+#include "SFCGAL/MultiLineString.h"
+#include "SFCGAL/MultiPoint.h"
+#include "SFCGAL/MultiPolygon.h"
+#include "SFCGAL/MultiSolid.h"
+#include "SFCGAL/Point.h"
+#include "SFCGAL/Polygon.h"
+#include "SFCGAL/PolyhedralSurface.h"
+#include "SFCGAL/Solid.h"
+#include "SFCGAL/Triangle.h"
+#include "SFCGAL/TriangulatedSurface.h"
+#include "SFCGAL/algorithm/isValid.h"
+#include "SFCGAL/detail/TestGeometry.h"
+#include "SFCGAL/io/wkt.h"
 
 using namespace boost::unit_test;
 using namespace SFCGAL;
@@ -83,7 +83,7 @@ BOOST_AUTO_TEST_CASE(geometryWithNan)
 BOOST_AUTO_TEST_CASE(disconnectedTIN)
 {
   std::unique_ptr<Geometry> const g(
-      io::readWkt("TIN(((0 0,1 0,0 1,0 0)),((2 0,3 0,2 1,2 0)))"));
+      io::readWkt("TIN (((0 0,1 0,0 1,0 0)),((2 0,3 0,2 1,2 0)))"));
   Validity const v = algorithm::isValid(*g);
   BOOST_CHECK(!v);
 }
