@@ -60,12 +60,12 @@ BOOST_AUTO_TEST_CASE(testEmpty)
 BOOST_AUTO_TEST_CASE(testSimple)
 {
   std::unique_ptr<Geometry> const gA(
-      io::readWkt("POLYGON((0 0,10 0,10 10,0 10,0 0))"));
+      io::readWkt("POLYGON ((0 0,10 0,10 10,0 10,0 0))"));
 
   std::unique_ptr<MultiPolygon> result(algorithm::offset(*gA, 1.0));
   BOOST_CHECK_EQUAL(
       result->asText(7),
-      "MULTIPOLYGON(((-1.0000000 10.0000000,-1.0000000 0.0000000,-0.8750000 "
+      "MULTIPOLYGON (((-1.0000000 10.0000000,-1.0000000 0.0000000,-0.8750000 "
       "-0.4841229,-0.7500000 -0.6614378,-0.6250000 -0.7806247,-0.5000000 "
       "-0.8660254,-0.3750000 -0.9270248,-0.2500000 -0.9682458,-0.1250000 "
       "-0.9921567,0.0000000 -1.0000000,10.0000000 -1.0000000,10.1250000 "
@@ -83,7 +83,7 @@ BOOST_AUTO_TEST_CASE(testSimple)
 BOOST_AUTO_TEST_CASE(testHoles)
 {
   std::unique_ptr<Geometry> const gA(
-      io::readWkt("POLYGON((13.652901 8.978070,13.921068 13.219992,20.454603 "
+      io::readWkt("POLYGON ((13.652901 8.978070,13.921068 13.219992,20.454603 "
                   "13.268750,18.967492 11.001516,16.432091 11.220926,15.091253 "
                   "13.024961,14.481782 11.976670,14.676813 10.708970,15.798240 "
                   "9.392511,16.358954 9.416890,16.870910 10.075119,16.797774 "
@@ -96,7 +96,7 @@ BOOST_AUTO_TEST_CASE(testHoles)
 
   // @todo works in Release, not in Debug... Something strange with holes?
   // BOOST_CHECK_EQUAL(result->asText(),
-  // "MULTIPOLYGON(((3562035796054625/281474976710656
+  // "MULTIPOLYGON (((3562035796054625/281474976710656
   // 2544860917657577/281474976710656,7123931396669903/562949953421312
   // 317964373056855/35184372088832,1780947800307639/140737488355328
   // 2542483596591303/281474976710656,890456375723901/70368744177664
@@ -191,28 +191,29 @@ BOOST_AUTO_TEST_CASE(testHoles)
 
 BOOST_AUTO_TEST_CASE(testPoint)
 {
-  std::unique_ptr<Geometry> const gA(io::readWkt("POINT(1 1)"));
+  std::unique_ptr<Geometry> const gA(io::readWkt("POINT (1 1)"));
   std::unique_ptr<MultiPolygon>   result(algorithm::offset(*gA, 1.0));
   BOOST_CHECK_EQUAL(
       result->asText(2),
-      "MULTIPOLYGON(((2.00 1.00,1.75 1.66,1.50 1.87,1.25 1.97,1.00 2.00,0.75 "
+      "MULTIPOLYGON (((2.00 1.00,1.75 1.66,1.50 1.87,1.25 1.97,1.00 2.00,0.75 "
       "1.97,0.50 1.87,0.25 1.66,0.00 1.00,0.25 0.34,0.50 0.13,0.75 0.03,1.00 "
       "0.00,1.25 0.03,1.50 0.13,1.75 0.34,2.00 1.00)))");
 }
 
 BOOST_AUTO_TEST_CASE(testLineString)
 {
-  std::unique_ptr<Geometry> const gA(
-      io::readWkt("LINESTRING(13.652901 8.978070,13.921068 13.219992,20.454603 "
-                  "13.268750,18.967492 11.001516,16.432091 11.220926,15.091253 "
-                  "13.024961,14.481782 11.976670,14.676813 10.708970,15.798240 "
-                  "9.392511,16.358954 9.416890,16.870910 10.075119,16.797774 "
-                  "10.952758,17.431624 11.001516,18.162990 10.099498,18.138611 "
-                  "8.368599,14.774328 9.416890,14.530540 8.929313,13.945447 "
-                  "8.441735,13.652901 8.978070)"));
+  std::unique_ptr<Geometry> const     gA(io::readWkt(
+      "LINESTRING (13.652901 8.978070,13.921068 13.219992,20.454603 "
+          "13.268750,18.967492 11.001516,16.432091 11.220926,15.091253 "
+          "13.024961,14.481782 11.976670,14.676813 10.708970,15.798240 "
+          "9.392511,16.358954 9.416890,16.870910 10.075119,16.797774 "
+          "10.952758,17.431624 11.001516,18.162990 10.099498,18.138611 "
+          "8.368599,14.774328 9.416890,14.530540 8.929313,13.945447 "
+          "8.441735,13.652901 8.978070)"));
   std::unique_ptr<MultiPolygon> const result(algorithm::offset(*gA, 0.5));
   //	BOOST_CHECK_EQUAL( result->asText(7),
-  //"MULTIPOLYGON(((20.9546030 13.2687500,20.8916366 13.5116525,20.8286702 13.6005236,20.7657038
+  //"MULTIPOLYGON
+  //(((20.9546030 13.2687500,20.8916366 13.5116525,20.8286702 13.6005236,20.7657038
   // 13.6601785,20.7027374 13.7028345,20.6397710 13.7331989,20.5768046 13.7535869,20.5138382
   // 13.7652288,20.4508718 13.7687361,17.1597259 13.7441753,13.9173367 13.7199781,13.8554277
   // 13.7156646,13.7935186 13.7034495,13.7316095 13.6827073,13.6697004 13.6522123,13.6077914
@@ -264,7 +265,7 @@ BOOST_AUTO_TEST_CASE(testLineString)
 BOOST_AUTO_TEST_CASE(testPolygonWithHoles)
 {
   std::unique_ptr<Geometry> const     gA(io::readWkt(
-      "POLYGON((11.966308 -10.211022,18.007885 1.872133,39.364158 "
+      "POLYGON ((11.966308 -10.211022,18.007885 1.872133,39.364158 "
           "2.434140,53.554839 -6.557975,43.438710 -22.856183,20.396416 "
           "-28.476254,5.643728 -25.525717,13.090323 -20.889158,32.479570 "
           "-21.310663,38.521147 -15.831093,46.248746 -9.087007,34.446595 "
@@ -277,7 +278,7 @@ BOOST_AUTO_TEST_CASE(testPolygonWithHoles)
 
   // @todo works in Release, not in Debug... Something strange with holes?
   // BOOST_CHECK_EQUAL(result->asText(),
-  // "MULTIPOLYGON(((3028360385708393/562949953421312
+  // "MULTIPOLYGON (((3028360385708393/562949953421312
   // -3532689497542891/140737488355328,3011773017246331/562949953421312
   // -1767740319401211/70368744177664,2995185648784269/562949953421312
   // -3538735168852129/140737488355328,5957196560644415/1125899906842624
@@ -434,11 +435,11 @@ BOOST_AUTO_TEST_CASE(testPolygonWithHoles)
 BOOST_AUTO_TEST_CASE(testMultiPoint)
 {
   std::unique_ptr<Geometry> const gA(
-      io::readWkt("MULTIPOINT(2 0,1 1,0 2,-1 1,-2 0,-1 -1,0 -2,1 -1)"));
+      io::readWkt("MULTIPOINT (2 0,1 1,0 2,-1 1,-2 0,-1 -1,0 -2,1 -1)"));
   std::unique_ptr<Geometry> const result(
       io::readWkt(algorithm::offset(*gA, 1.0)->asText(7)));
   std::unique_ptr<Geometry> const expected(io::readWkt(
-      "MULTIPOLYGON(((3.0000000 0.0000000,2.8750000 0.4841229,2.7500000 "
+      "MULTIPOLYGON (((3.0000000 0.0000000,2.8750000 0.4841229,2.7500000 "
       "0.6614378,2.6250000 0.7806247,2.5000000 0.8660254,2.3750000 "
       "0.9270248,2.2500000 0.9682458,2.1250000 0.9921567,2.0000000 "
       "1.0000000,1.8750000 1.4841229,1.7500000 1.6614378,1.6250000 "
@@ -484,10 +485,10 @@ BOOST_AUTO_TEST_CASE(testMultiPoint)
 BOOST_AUTO_TEST_CASE(testMultiLineString)
 {
   std::unique_ptr<Geometry> const gA(
-      io::readWkt("MULTILINESTRING((0.0 0.0,1.0 0.0),(2.0 2.0,3.0 2.0))"));
+      io::readWkt("MULTILINESTRING ((0.0 0.0,1.0 0.0),(2.0 2.0,3.0 2.0))"));
   std::unique_ptr<Geometry>       result{algorithm::offset(*gA, 1.0)};
   std::unique_ptr<Geometry> const expected{io::readWkt(
-      "MULTIPOLYGON(((2/1 0/1,15/8 4360591588697965/9007199254740992,7/4 "
+      "MULTIPOLYGON (((2/1 0/1,15/8 4360591588697965/9007199254740992,7/4 "
       "2978851154656373/4503599627370496,13/8 "
       "3515621332314565/4503599627370496,3/2 "
       "3900231685776981/4503599627370496,11/8 "
@@ -550,10 +551,10 @@ BOOST_AUTO_TEST_CASE(testMultiLineString)
 BOOST_AUTO_TEST_CASE(testMultiPolygon)
 {
   std::unique_ptr<Geometry> const gA(
-      io::readWkt("MULTIPOLYGON(((0 0,1 0,1 1,0 0)),((2 1,2 0,3 0,2 1)))"));
+      io::readWkt("MULTIPOLYGON (((0 0,1 0,1 1,0 0)),((2 1,2 0,3 0,2 1)))"));
   std::unique_ptr<Geometry>       result{algorithm::offset(*gA, 1.0)};
   std::unique_ptr<Geometry> const expected{io::readWkt(
-      "MULTIPOLYGON(((-3184560061929027/4503599627370496 "
+      "MULTIPOLYGON (((-3184560061929027/4503599627370496 "
       "1592245805114451/2251799813685248,-6698880015218421/9007199254740992 "
       "1505295754916495/2251799813685248,-1757159976644697/2251799813685248 "
       "2816374419278037/4503599627370496,-1839599949484789/2251799813685248 "
@@ -627,11 +628,11 @@ BOOST_AUTO_TEST_CASE(testMultiPolygon)
 BOOST_AUTO_TEST_CASE(testGeometryCollection)
 {
   std::unique_ptr<Geometry> const gA(
-      io::readWkt("GEOMETRYCOLLECTION(POINT(0 0),LINESTRING(1 1,2 2))"));
+      io::readWkt("GEOMETRYCOLLECTION (POINT (0 0),LINESTRING (1 1,2 2))"));
   std::unique_ptr<Geometry> const result(
       io::readWkt(algorithm::offset(*gA, 1.0)->asText(2)));
   std::unique_ptr<Geometry> const expected(io::readWkt(
-      "MULTIPOLYGON(((-0.00 1.00,-0.12 0.99,-0.25 0.97,-0.38 0.93,-0.50 "
+      "MULTIPOLYGON (((-0.00 1.00,-0.12 0.99,-0.25 0.97,-0.38 0.93,-0.50 "
       "0.87,-0.62 0.78,-0.75 0.66,-0.88 0.48,-1.00 0.00,-0.75 -0.66,-0.50 "
       "-0.87,-0.25 -0.97,0.00 -1.00,0.25 -0.97,0.50 -0.87,0.75 -0.66,1.00 "
       "0.00,1.09 0.00,1.18 0.02,1.27 0.04,1.35 0.06,1.44 0.10,1.53 0.15,1.62 "
