@@ -20,23 +20,23 @@
  */
 #include <boost/test/unit_test.hpp>
 
-#include <SFCGAL/GeometryCollection.h>
-#include <SFCGAL/Kernel.h>
-#include <SFCGAL/LineString.h>
-#include <SFCGAL/MultiLineString.h>
-#include <SFCGAL/MultiPoint.h>
-#include <SFCGAL/MultiPolygon.h>
-#include <SFCGAL/MultiSolid.h>
-#include <SFCGAL/Point.h>
-#include <SFCGAL/Polygon.h>
-#include <SFCGAL/PolyhedralSurface.h>
-#include <SFCGAL/Solid.h>
-#include <SFCGAL/Triangle.h>
-#include <SFCGAL/TriangulatedSurface.h>
-#include <SFCGAL/algorithm/translate.h>
-#include <SFCGAL/io/wkt.h>
+#include "SFCGAL/GeometryCollection.h"
+#include "SFCGAL/Kernel.h"
+#include "SFCGAL/LineString.h"
+#include "SFCGAL/MultiLineString.h"
+#include "SFCGAL/MultiPoint.h"
+#include "SFCGAL/MultiPolygon.h"
+#include "SFCGAL/MultiSolid.h"
+#include "SFCGAL/Point.h"
+#include "SFCGAL/Polygon.h"
+#include "SFCGAL/PolyhedralSurface.h"
+#include "SFCGAL/Solid.h"
+#include "SFCGAL/Triangle.h"
+#include "SFCGAL/TriangulatedSurface.h"
+#include "SFCGAL/algorithm/translate.h"
+#include "SFCGAL/io/wkt.h"
 
-#include <SFCGAL/detail/tools/Registry.h>
+#include "SFCGAL/detail/tools/Registry.h"
 
 using namespace boost::unit_test;
 using namespace SFCGAL;
@@ -53,7 +53,7 @@ BOOST_AUTO_TEST_CASE(testEmpty)
     BOOST_TEST_MESSAGE(typeName);
 
     std::unique_ptr<Geometry> g(registry.newGeometryByTypeName(typeName));
-    BOOST_REQUIRE(g.get() != NULL);
+    BOOST_REQUIRE(g.get() != nullptr);
     algorithm::translate(*g, 1.0, 1.0, 1.0);
     BOOST_CHECK(g->isEmpty());
   }
