@@ -20,8 +20,8 @@
  */
 #include <boost/test/unit_test.hpp>
 
-#include <SFCGAL/detail/graph/GeometryGraph.h>
-#include <SFCGAL/detail/graph/GeometryGraphBuilder.h>
+#include "SFCGAL/detail/graph/GeometryGraph.h"
+#include "SFCGAL/detail/graph/GeometryGraphBuilder.h"
 
 using namespace boost::unit_test;
 
