@@ -20,7 +20,7 @@
  */
 #include <boost/test/unit_test.hpp>
 
-#include <SFCGAL/detail/graph/GeometryGraph.h>
+#include "SFCGAL/detail/graph/GeometryGraph.h"
 
 using namespace boost::unit_test;
 using namespace SFCGAL;
