@@ -20,11 +20,11 @@
  */
 #include <boost/test/unit_test.hpp>
 
-#include <SFCGAL/Kernel.h>
-#include <SFCGAL/Polygon.h>
-#include <SFCGAL/detail/io/WktWriter.h>
-#include <SFCGAL/detail/transform/ForceZOrderPoints.h>
-#include <SFCGAL/io/wkt.h>
+#include "SFCGAL/Kernel.h"
+#include "SFCGAL/Polygon.h"
+#include "SFCGAL/detail/io/WktWriter.h"
+#include "SFCGAL/detail/transform/ForceZOrderPoints.h"
+#include "SFCGAL/io/wkt.h"
 
 using namespace boost::unit_test;
 using namespace SFCGAL;
@@ -33,7 +33,7 @@ BOOST_AUTO_TEST_SUITE(SFCGAL_transform_ForceZOrderPointsTest)
 
 BOOST_AUTO_TEST_CASE(simple)
 {
-  std::unique_ptr<Geometry> g1 = io::readWkt("POLYGON((0 0,0 1,1 1,1 0,0 0))");
+  std::unique_ptr<Geometry> g1 = io::readWkt("POLYGON ((0 0,0 1,1 1,1 0,0 0))");
 
   const Polygon &p = g1->as<Polygon>();
   BOOST_CHECK(!p.isCounterClockWiseOriented());
